# shirkhan

the python tool for shirkhan
> currently using with project u-open-imla

# Usage

```shell
pip install shirkhan
```

```python
from shirkhan import decode, encode, syllabify

encode("xxxx")
decode("yyy")
word = "شىرخان"
print(syllabify(word))

```

> 更多使用案例请看 examples目录中的脚本

# 开发，贡献指南

- 本地安装项目，安装时指定可编辑方式安装，这样可以边使用边看效果，甚至调整逻辑时不需要频繁修改源码后重新安装

```shell
pip install --editable shirkhan_lib_path // 这个目录指定到有setup.py为止即可

```